@@ -93,7 +93,6 @@ class Circuit:
         else:
             self.has_inputs = False
         self.split = split
-        # TODO(@refraction-ray): split settings at global level?
         if (inputs is None) and (mps_inputs is None):
             nodes = [
                 tn.Node(
@@ -1216,6 +1215,23 @@ class Circuit:
 
     state = wavefunction
 
+    def get_quoperator(self) -> QuOperator:
+        """
+        Get the ``QuOperator`` MPO like representation of the circuit unitary without contraction.
+
+        :return: ``QuOperator`` object for the circuit unitary (open indices for the input state)
+        :rtype: QuOperator
+        """
+        mps = identity([2 for _ in range(self._nqubits)])
+        c = Circuit(self._nqubits)
+        ns, es = self._copy()
+        c._nodes = ns
+        c._front = es
+        c.replace_mps_inputs(mps)
+        return QuOperator(c._front[: self._nqubits], c._front[self._nqubits :])
+
+    quoperator = get_quoperator
+
     def matrix(self) -> Tensor:
         """
         Get the unitary matrix for the circuit irrespective with the circuit input state.
@@ -1703,7 +1719,7 @@ def expectation(
     >>> tc.expectation(*x1x2, ket=s3, bra=s2)
     (0.7071067690849304+0j) # 1/sqrt(2)
 
-    :param ket: :math:`ket`.
+    :param ket: :math:`ket`. The state in tensor or ``QuVector`` format
     :type ket: Tensor
     :param bra: :math:`bra`, defaults to None, which is the same as ``ket``.
     :type bra: Optional[Tensor], optional
@@ -1715,7 +1731,6 @@ def expectation(
     :return: The result of :math:`\\langle bra\\vert ops \\vert ket\\rangle`.
     :rtype: Tensor
     """
-    # TODO: incomplete docstring
     if bra is None:
         bra = ket
     if isinstance(ket, QuOperator):
